pub struct KernelLaunchStats { /* private fields */ }Expand description
Per-kernel aggregate statistics within a LaunchSummary.
Implementations
Sourceimpl KernelLaunchStats
impl KernelLaunchStats
Sourcepub fn kernel_name(&self) -> &str
pub fn kernel_name(&self) -> &str
Returns the kernel function name.
Sourcepub fn launch_count(&self) -> usize
pub fn launch_count(&self) -> usize
Returns the number of launches recorded for this kernel.
Sourcepub fn total_threads(&self) -> u64
pub fn total_threads(&self) -> u64
Returns the total number of threads across all launches.
Returns the total shared memory bytes across all launches.