pub struct AsyncLaunchConfig {
pub poll_strategy: PollStrategy,
pub timeout: Option<Duration>,
}Expand description
Configuration for async kernel launch behaviour.
Fields
poll_strategy: PollStrategyStrategy for polling event completion.
timeout: Option<Duration>Optional maximum time to wait before the future resolves with a timeout error.
Implementations
Sourceimpl AsyncLaunchConfig
impl AsyncLaunchConfig
Sourcepub fn new(poll_strategy: PollStrategy) -> Self
pub fn new(poll_strategy: PollStrategy) -> Self
Creates a new config with the given poll strategy and no timeout.
Sourcepub fn with_timeout(self, timeout: Duration) -> Self
pub fn with_timeout(self, timeout: Duration) -> Self
Sets the timeout duration.