pub unsafe trait SerializableKernelArgs: KernelArgs {
// Required method
fn serialize_args(&self) -> Vec<SerializedArg>;
}Expand description
Extension trait for KernelArgs that can serialize arguments
into SerializedArg form for logging and debugging.
Safety
Implementors must uphold the same invariants as KernelArgs.
The serialized arguments must correspond one-to-one with the
pointers returned by as_param_ptrs.
Required Methods
Sourcefn serialize_args(&self) -> Vec<SerializedArg>
fn serialize_args(&self) -> Vec<SerializedArg>
Serializes the kernel arguments into a vector of SerializedArg.
Implementations on Foreign Types
Sourceimpl SerializableKernelArgs for ()
impl SerializableKernelArgs for ()
fn serialize_args(&self) -> Vec<SerializedArg>
Sourceimpl<A: Copy + SerializeArg> SerializableKernelArgs for (A,)
Safety
The serialized arguments correspond one-to-one with the pointers
from as_param_ptrs.
impl<A: Copy + SerializeArg> SerializableKernelArgs for (A,)
Safety
The serialized arguments correspond one-to-one with the pointers
from as_param_ptrs.
fn serialize_args(&self) -> Vec<SerializedArg>
Sourceimpl<A: Copy + SerializeArg, B: Copy + SerializeArg> SerializableKernelArgs for (A, B)
Safety
The serialized arguments correspond one-to-one with the pointers
from as_param_ptrs.
impl<A: Copy + SerializeArg, B: Copy + SerializeArg> SerializableKernelArgs for (A, B)
Safety
The serialized arguments correspond one-to-one with the pointers
from as_param_ptrs.
fn serialize_args(&self) -> Vec<SerializedArg>
Sourceimpl<A: Copy + SerializeArg, B: Copy + SerializeArg, C: Copy + SerializeArg> SerializableKernelArgs for (A, B, C)
Safety
The serialized arguments correspond one-to-one with the pointers
from as_param_ptrs.
impl<A: Copy + SerializeArg, B: Copy + SerializeArg, C: Copy + SerializeArg> SerializableKernelArgs for (A, B, C)
Safety
The serialized arguments correspond one-to-one with the pointers
from as_param_ptrs.
fn serialize_args(&self) -> Vec<SerializedArg>
Sourceimpl<A: Copy + SerializeArg, B: Copy + SerializeArg, C: Copy + SerializeArg, D: Copy + SerializeArg> SerializableKernelArgs for (A, B, C, D)
Safety
The serialized arguments correspond one-to-one with the pointers
from as_param_ptrs.
impl<A: Copy + SerializeArg, B: Copy + SerializeArg, C: Copy + SerializeArg, D: Copy + SerializeArg> SerializableKernelArgs for (A, B, C, D)
Safety
The serialized arguments correspond one-to-one with the pointers
from as_param_ptrs.
fn serialize_args(&self) -> Vec<SerializedArg>
Sourceimpl<A: Copy + SerializeArg, B: Copy + SerializeArg, C: Copy + SerializeArg, D: Copy + SerializeArg, E: Copy + SerializeArg> SerializableKernelArgs for (A, B, C, D, E)
Safety
The serialized arguments correspond one-to-one with the pointers
from as_param_ptrs.
impl<A: Copy + SerializeArg, B: Copy + SerializeArg, C: Copy + SerializeArg, D: Copy + SerializeArg, E: Copy + SerializeArg> SerializableKernelArgs for (A, B, C, D, E)
Safety
The serialized arguments correspond one-to-one with the pointers
from as_param_ptrs.
fn serialize_args(&self) -> Vec<SerializedArg>
Sourceimpl<A: Copy + SerializeArg, B: Copy + SerializeArg, C: Copy + SerializeArg, D: Copy + SerializeArg, E: Copy + SerializeArg, F: Copy + SerializeArg> SerializableKernelArgs for (A, B, C, D, E, F)
Safety
The serialized arguments correspond one-to-one with the pointers
from as_param_ptrs.
impl<A: Copy + SerializeArg, B: Copy + SerializeArg, C: Copy + SerializeArg, D: Copy + SerializeArg, E: Copy + SerializeArg, F: Copy + SerializeArg> SerializableKernelArgs for (A, B, C, D, E, F)
Safety
The serialized arguments correspond one-to-one with the pointers
from as_param_ptrs.
fn serialize_args(&self) -> Vec<SerializedArg>
Sourceimpl<A: Copy + SerializeArg, B: Copy + SerializeArg, C: Copy + SerializeArg, D: Copy + SerializeArg, E: Copy + SerializeArg, F: Copy + SerializeArg, G: Copy + SerializeArg> SerializableKernelArgs for (A, B, C, D, E, F, G)
Safety
The serialized arguments correspond one-to-one with the pointers
from as_param_ptrs.
impl<A: Copy + SerializeArg, B: Copy + SerializeArg, C: Copy + SerializeArg, D: Copy + SerializeArg, E: Copy + SerializeArg, F: Copy + SerializeArg, G: Copy + SerializeArg> SerializableKernelArgs for (A, B, C, D, E, F, G)
Safety
The serialized arguments correspond one-to-one with the pointers
from as_param_ptrs.
fn serialize_args(&self) -> Vec<SerializedArg>
Sourceimpl<A: Copy + SerializeArg, B: Copy + SerializeArg, C: Copy + SerializeArg, D: Copy + SerializeArg, E: Copy + SerializeArg, F: Copy + SerializeArg, G: Copy + SerializeArg, H: Copy + SerializeArg> SerializableKernelArgs for (A, B, C, D, E, F, G, H)
Safety
The serialized arguments correspond one-to-one with the pointers
from as_param_ptrs.
impl<A: Copy + SerializeArg, B: Copy + SerializeArg, C: Copy + SerializeArg, D: Copy + SerializeArg, E: Copy + SerializeArg, F: Copy + SerializeArg, G: Copy + SerializeArg, H: Copy + SerializeArg> SerializableKernelArgs for (A, B, C, D, E, F, G, H)
Safety
The serialized arguments correspond one-to-one with the pointers
from as_param_ptrs.
fn serialize_args(&self) -> Vec<SerializedArg>
Sourceimpl<A: Copy + SerializeArg, B: Copy + SerializeArg, C: Copy + SerializeArg, D: Copy + SerializeArg, E: Copy + SerializeArg, F: Copy + SerializeArg, G: Copy + SerializeArg, H: Copy + SerializeArg, I: Copy + SerializeArg> SerializableKernelArgs for (A, B, C, D, E, F, G, H, I)
Safety
The serialized arguments correspond one-to-one with the pointers
from as_param_ptrs.
impl<A: Copy + SerializeArg, B: Copy + SerializeArg, C: Copy + SerializeArg, D: Copy + SerializeArg, E: Copy + SerializeArg, F: Copy + SerializeArg, G: Copy + SerializeArg, H: Copy + SerializeArg, I: Copy + SerializeArg> SerializableKernelArgs for (A, B, C, D, E, F, G, H, I)
Safety
The serialized arguments correspond one-to-one with the pointers
from as_param_ptrs.
fn serialize_args(&self) -> Vec<SerializedArg>
Sourceimpl<A: Copy + SerializeArg, B: Copy + SerializeArg, C: Copy + SerializeArg, D: Copy + SerializeArg, E: Copy + SerializeArg, F: Copy + SerializeArg, G: Copy + SerializeArg, H: Copy + SerializeArg, I: Copy + SerializeArg, J: Copy + SerializeArg> SerializableKernelArgs for (A, B, C, D, E, F, G, H, I, J)
Safety
The serialized arguments correspond one-to-one with the pointers
from as_param_ptrs.
impl<A: Copy + SerializeArg, B: Copy + SerializeArg, C: Copy + SerializeArg, D: Copy + SerializeArg, E: Copy + SerializeArg, F: Copy + SerializeArg, G: Copy + SerializeArg, H: Copy + SerializeArg, I: Copy + SerializeArg, J: Copy + SerializeArg> SerializableKernelArgs for (A, B, C, D, E, F, G, H, I, J)
Safety
The serialized arguments correspond one-to-one with the pointers
from as_param_ptrs.
fn serialize_args(&self) -> Vec<SerializedArg>
Sourceimpl<A: Copy + SerializeArg, B: Copy + SerializeArg, C: Copy + SerializeArg, D: Copy + SerializeArg, E: Copy + SerializeArg, F: Copy + SerializeArg, G: Copy + SerializeArg, H: Copy + SerializeArg, I: Copy + SerializeArg, J: Copy + SerializeArg, K: Copy + SerializeArg> SerializableKernelArgs for (A, B, C, D, E, F, G, H, I, J, K)
Safety
The serialized arguments correspond one-to-one with the pointers
from as_param_ptrs.
impl<A: Copy + SerializeArg, B: Copy + SerializeArg, C: Copy + SerializeArg, D: Copy + SerializeArg, E: Copy + SerializeArg, F: Copy + SerializeArg, G: Copy + SerializeArg, H: Copy + SerializeArg, I: Copy + SerializeArg, J: Copy + SerializeArg, K: Copy + SerializeArg> SerializableKernelArgs for (A, B, C, D, E, F, G, H, I, J, K)
Safety
The serialized arguments correspond one-to-one with the pointers
from as_param_ptrs.
fn serialize_args(&self) -> Vec<SerializedArg>
Sourceimpl<A: Copy + SerializeArg, B: Copy + SerializeArg, C: Copy + SerializeArg, D: Copy + SerializeArg, E: Copy + SerializeArg, F: Copy + SerializeArg, G: Copy + SerializeArg, H: Copy + SerializeArg, I: Copy + SerializeArg, J: Copy + SerializeArg, K: Copy + SerializeArg, L: Copy + SerializeArg> SerializableKernelArgs for (A, B, C, D, E, F, G, H, I, J, K, L)
Safety
The serialized arguments correspond one-to-one with the pointers
from as_param_ptrs.
impl<A: Copy + SerializeArg, B: Copy + SerializeArg, C: Copy + SerializeArg, D: Copy + SerializeArg, E: Copy + SerializeArg, F: Copy + SerializeArg, G: Copy + SerializeArg, H: Copy + SerializeArg, I: Copy + SerializeArg, J: Copy + SerializeArg, K: Copy + SerializeArg, L: Copy + SerializeArg> SerializableKernelArgs for (A, B, C, D, E, F, G, H, I, J, K, L)
Safety
The serialized arguments correspond one-to-one with the pointers
from as_param_ptrs.